==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/LinksAerialConsentGranted.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectRevokeAerialConsent;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksAerialConsentGranted
 */
@JsonPropertyOrder({ LinksAerialConsentGranted.JSON_PROPERTY_SELF, LinksAerialConsentGranted.JSON_PROPERTY_REVOKE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class LinksAerialConsentGranted implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_REVOKE = "revoke";
    private HrefObjectRevokeAerialConsent revoke;

    public LinksAerialConsentGranted() {
    }

    public LinksAerialConsentGranted self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksAerialConsentGranted revoke(HrefObjectRevokeAerialConsent revoke) {

        this.revoke = revoke;
        return this;
    }

    /**
     * Get revoke
     *
     * @return revoke
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REVOKE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectRevokeAerialConsent getRevoke() {
        return revoke;
    }

    @JsonProperty(JSON_PROPERTY_REVOKE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevoke(HrefObjectRevokeAerialConsent revoke) {
        this.revoke = revoke;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksAerialConsentGranted linksAerialConsentGranted = (LinksAerialConsentGranted) o;
        return Objects.equals(this.self, linksAerialConsentGranted.self)
                && Objects.equals(this.revoke, linksAerialConsentGranted.revoke);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, revoke);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksAerialConsentGranted {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    revoke: ").append(toIndentedString(revoke)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: com/okta/sdk/resource/model/LinksAerialConsentGranted.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObjectRevokeAerialConsent;
import com.okta.sdk.resource.model.HrefObjectSelfLink;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * LinksAerialConsentGranted
 */
@JsonPropertyOrder({ LinksAerialConsentGranted.JSON_PROPERTY_SELF, LinksAerialConsentGranted.JSON_PROPERTY_REVOKE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class LinksAerialConsentGranted implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObjectSelfLink self;

    public static final String JSON_PROPERTY_REVOKE = "revoke";
    private HrefObjectRevokeAerialConsent revoke;

    public LinksAerialConsentGranted() {
    }

    public LinksAerialConsentGranted self(HrefObjectSelfLink self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectSelfLink getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObjectSelfLink self) {
        this.self = self;
    }

    public LinksAerialConsentGranted revoke(HrefObjectRevokeAerialConsent revoke) {

        this.revoke = revoke;
        return this;
    }

    /**
     * Get revoke
     *
     * @return revoke
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_REVOKE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObjectRevokeAerialConsent getRevoke() {
        return revoke;
    }

    @JsonProperty(JSON_PROPERTY_REVOKE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRevoke(HrefObjectRevokeAerialConsent revoke) {
        this.revoke = revoke;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        LinksAerialConsentGranted linksAerialConsentGranted = (LinksAerialConsentGranted) o;
        return Objects.equals(this.self, linksAerialConsentGranted.self)
                && Objects.equals(this.revoke, linksAerialConsentGranted.revoke);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, revoke);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class LinksAerialConsentGranted {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    revoke: ").append(toIndentedString(revoke)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
